
*Extract income groups
use "${inputdata}Other\CLASS_FY24.dta", clear
keep if year_data == 2019
keep code incgroup_historical
save "inc_group", replace

*Global distribution 
use "${inputdata}PIP\GlobalDist1000bins_1990_2024_3pr24.dta", clear
keep if inlist(year,2019,2020)
gen mld_within = .
gen mld_between = .
*Create numeric country code and extract a file which has the match with the alphabetic code 
encode(code), gen(code_num)
preserve
	keep code code_num
	duplicates drop
	save code_match, replace
restore
*generate variables for each country to store pop share, ge0 and relative mean
sum code_num
	global min=r(min)
	global max=r(max)
qui forval c = $min/$max {
	gen v_`c'=.				// population share
	gen ge0_`c'=.			// within-group inequality	
	gen lambda_`c'=.		// relative mean (m_k/m)
}
*Loop over years and then each country to extract the contributions to within and between inequality
sum year
forval yr = `r(min)'/`r(max)' {
	qui ineqdeco welf [aw=pop] if year==`yr', by(code_num)
	replace mld_within  = `r(within_ge0)' if year==`yr'
	replace mld_between  = `r(between_ge0)' if year==`yr'
	forval c = $min/$max {
		 replace v_`c' 		= `r(v_`c')' 		if year==`yr'
		 replace ge0_`c' 	= `r(ge0_`c')' 		if year==`yr'
		 replace lambda_`c' = `r(lambda_`c')' 	if year==`yr'
	}
} 
collapse welf mld_within mld_between v_1-lambda_218 (rawsum) pop [aw=pop], by(year)
*save "country_level_decomp_temp1.dta", replace

*Create a long dataset and cleanup
reshape long v_ ge0_ lambda_, i (year) j(code_num)
ren v_ v
ren ge0_ ge0
ren lambda_ lambda
label variable v 		"population share"
label variable ge0 		"within-group inequality"
label variable lambda 	"relative mean (m_k/m)"
*Merge the alphabetic country code and the income group
merge m:1 code_num using "code_match"
drop _merge	// check that all merged
merge m:1 code using "inc_group"
drop _merge // check that all merged

*Create the within and between contributions (for each country-year):
gen w=v*ge0
gen b=v*ln((lambda)^(-1))

*Check: the sum of the country-level contributions should be the same as the overall between and within share
preserve 
	collapse (mean) mld_within mld_between (sum) w b, by(year)
	gen a=w-mld_within
	gen c=b-mld_between
	su a c 		// these should be zero
restore
label variable incgroup_historical 	"Income group using 2019 data"
label variable mld_within			"MLD global within"
label variable mld_between			"MLD global between"
label variable w					"MLD country contribution within"
label variable b					"MLD country contribution between"
save "${output}decomp_country", replace

*Collapse by income groups:
collapse (mean) mld_within mld_between (sum) w b, by(year incgroup_historical)
*Check: the sum of income-groups should be the same as overall
preserve
	collapse (mean) mld_within mld_between (sum) w b, by(year)
	gen a=w-mld_within
	gen c=b-mld_between
	su a c 		// these should be zero
restore
label variable incgroup_historical 	"Income group using 2019 data"
label variable mld_within			"MLD global within"
label variable mld_between			"MLD global between"
label variable w					"MLD inc group within"
label variable b					"MLD inc group between"
save "${output}decomp_incgroup", replace

*Transform to look at changes by income group:
reshape wide mld_within mld_between w b, i(incgroup_historical) j(year)
foreach var in mld_within mld_between w b {
	gen d_`var'=`var'2020-`var'2019
	drop `var'2020 `var'2019
}
label variable d_mld_within		"difference MLD global within"
label variable d_mld_between	"difference MLD global beween"
label variable d_w				"difference MLD inc group within"
label variable d_b				"difference MLD inc group between"
*Check: the sum of the changes should add up to the total changes
preserve
	collapse (mean) d_mld_within d_mld_between (sum) d_w d_b
	gen a=d_w-d_mld_within
	gen c=d_b-d_mld_between
	su a c 		// these should be zero
restore
   
*Multiply by 100
gen changewithin  = d_w * 100
gen changebetween = d_b * 100

gen 	incgnum = 1 if incgroup_historical=="Low income"
replace incgnum = 2 if incgroup_historical=="Lower middle income"
replace incgnum = 3 if incgroup_historical=="Upper middle income"
replace incgnum = 4 if incgroup_historical=="High income"
	
graph bar changewithin changebetween, stack over(incgroup_historical, sort(incgnum)) ///
	bar(1, c(gs0)) bar(2, c(gs8)) ytitle("Change in mean log deviation (x100)") ///
	yline(0, lp(shortdash) lc(gs8)) ///
	legend(ring(1) pos(6) row(1) order(1 "Within-country" 2 "Between-country"))

graph export "${figntab}Fig4.png", replace as(png)

*clean up: 	
cap erase "inc_group.dta"
cap erase "code_match.dta"
cap erase "decomp_country.dta"
cap erase "decomp_incgroup.dta"


********************************************************************************
exit